"""Delete alert uniqueness

Revision ID: 90c1158cc2ba
Revises: 0d7bea8f4d60
Create Date: 2025-08-05 00:17:10.987834

"""

from typing import Sequence, Union

import sqlalchemy as sa

from alembic import op

# revision identifiers, used by Alembic.
revision: str = "90c1158cc2ba"
down_revision: Union[str, None] = "0d7bea8f4d60"
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_constraint(
        "alert_definition_tenant_meter_id_key", "alert_definition", type_="unique"
    )
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_unique_constraint(
        "alert_definition_tenant_meter_id_key",
        "alert_definition",
        ["tenant", "meter_id"],
    )
    # ### end Alembic commands ###
